==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ContraptionInteractionPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import net.minecraft.class_1268;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ContraptionInteractionPacket(
    class_1268 hand, int target, class_2338 localPos, class_2350 face
) implements class_2596<class_2792> {
    public static final class_9139<class_9129, ContraptionInteractionPacket> CODEC = class_9139.method_56905(
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.HAND),
        ContraptionInteractionPacket::hand,
        class_9135.field_49675,
        ContraptionInteractionPacket::target,
        class_2338.field_48404,
        ContraptionInteractionPacket::localPos,
        class_2350.field_48450,
        ContraptionInteractionPacket::face,
        ContraptionInteractionPacket::new
    );

    public ContraptionInteractionPacket(AbstractContraptionEntity target, class_1268 hand, class_2338 localPos, class_2350 side) {
        this(hand, target.method_5628(), localPos, side);
    }

    @Override
    public void handle(class_2792 listener) {
        AllHandle.onContraptionInteraction((class_3244) listener, this);
    }

    @Override
    public class_9145<ContraptionInteractionPacket> method_65080() {
        return AllPackets.CONTRAPTION_INTERACT;
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ContraptionInteractionPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.contraptions.AbstractContraptionEntity;
import java.util.function.BiConsumer;
import net.minecraft.class_1268;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ContraptionInteractionPacket(class_1268 hand, int target, class_2338 localPos, class_2350 face) implements C2SPacket {
    public static final class_9139<class_9129, ContraptionInteractionPacket> CODEC = class_9139.method_56905(
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.HAND),
        ContraptionInteractionPacket::hand,
        class_9135.field_49675,
        ContraptionInteractionPacket::target,
        class_2338.field_48404,
        ContraptionInteractionPacket::localPos,
        class_2350.field_48450,
        ContraptionInteractionPacket::face,
        ContraptionInteractionPacket::new
    );

    public ContraptionInteractionPacket(AbstractContraptionEntity target, class_1268 hand, class_2338 localPos, class_2350 side) {
        this(hand, target.method_5628(), localPos, side);
    }

    @Override
    public boolean runInMain() {
        return true;
    }

    @Override
    public class_9145<ContraptionInteractionPacket> method_65080() {
        return AllPackets.CONTRAPTION_INTERACT;
    }

    @Override
    public BiConsumer<class_3244, ContraptionInteractionPacket> callback() {
        return AllHandle::onContraptionInteraction;
    }
}
